package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.ServiceCate;

/**
 * 服务分类Service接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IServiceCateService 
{
    /**
     * 查询服务分类
     * 
     * @param id 服务分类主键
     * @return 服务分类
     */
    public ServiceCate selectServiceCateById(Long id);

    /**
     * 查询服务分类列表
     * 
     * @param serviceCate 服务分类
     * @return 服务分类集合
     */
    public List<ServiceCate> selectServiceCateList(ServiceCate serviceCate);

    /**
     * 新增服务分类
     * 
     * @param serviceCate 服务分类
     * @return 结果
     */
    public int insertServiceCate(ServiceCate serviceCate);

    /**
     * 修改服务分类
     * 
     * @param serviceCate 服务分类
     * @return 结果
     */
    public int updateServiceCate(ServiceCate serviceCate);

    /**
     * 批量删除服务分类
     * 
     * @param ids 需要删除的服务分类主键集合
     * @return 结果
     */
    public int deleteServiceCateByIds(Long[] ids);

    /**
     * 删除服务分类信息
     * 
     * @param id 服务分类主键
     * @return 结果
     */
    public int deleteServiceCateById(Long id);
}
