package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.QuoteMaterialType;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ServiceCate;
import com.ruoyi.system.service.IServiceCateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务分类Controller
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
@RestController
@RequestMapping("/system/ServiceCate")
public class ServiceCateController extends BaseController
{
    @Autowired
    private IServiceCateService serviceCateService;

    /**
     * 查询服务分类列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:list')")
    @GetMapping("/list")
    public TableDataInfo list(ServiceCate serviceCate)
    {
        startPage();
        List<ServiceCate> list = serviceCateService.selectServiceCateList(serviceCate);
        return getDataTable(list);
    }

    /**
     * 导出服务分类列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:export')")
    @Log(title = "服务分类", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ServiceCate serviceCate)
    {
        List<ServiceCate> list = serviceCateService.selectServiceCateList(serviceCate);
        ExcelUtil<ServiceCate> util = new ExcelUtil<ServiceCate>(ServiceCate.class);
        util.exportExcel(response, list, "服务分类数据");
    }

    /**
     * 获取服务分类详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(serviceCateService.selectServiceCateById(id));
    }

    /**
     * 新增服务分类
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:add')")
    @Log(title = "服务分类", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ServiceCate serviceCate)
    {
        return toAjax(serviceCateService.insertServiceCate(serviceCate));
    }

    /**
     * 修改服务分类
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:edit')")
    @Log(title = "服务分类", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ServiceCate serviceCate)
    {
        return toAjax(serviceCateService.updateServiceCate(serviceCate));
    }
    /**
     * 定时任务状态修改
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:changeStatus')")
    @Log(title = "修改状态", businessType = BusinessType.UPDATE)
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody ServiceCate serviceCate)
    {
        ServiceCate newserviceCate = serviceCateService.selectServiceCateById(serviceCate.getId());
        newserviceCate.setStatus(serviceCate.getStatus());
        return toAjax(serviceCateService.updateServiceCate(newserviceCate));
    }
    /**
     * 删除服务分类
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceCate:remove')")
    @Log(title = "服务分类", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(serviceCateService.deleteServiceCateByIds(ids));
    }
}
